@@ -89,7 +89,7 @@ func TestAvailabilityZone(t *testing.T) {
 			machineScope, err := newMachineScope(machineScopeParams{
 				client:  fakeClient,
 				machine: machine,
-				awsClientBuilder: func(client runtimeclient.Client, secretName, namespace, region string) (awsclient.Client, error) {
+				awsClientBuilder: func(client runtimeclient.Client, secretName, namespace, region string, configManagedClient runtimeclient.Client) (awsclient.Client, error) {
 					return mockAWSClient, nil
 				},
 			})
@@ -367,7 +367,7 @@ func TestCreate(t *testing.T) {
 				SecurityGroups: []awsproviderv1.AWSResourceReference{{
 					Filters: []awsproviderv1.Filter{{
 						Name:   "tag:Name",
-						Values: []string{fmt.Sprintf("%s-%s-sg", clusterID, "role")},
+						Values: []string{fmt.Sprintf("%s-%s-sg", stubClusterID, "role")},
 					}},
 				}},
 				PublicIP: aws.Bool(true),
@@ -393,7 +393,7 @@ func TestCreate(t *testing.T) {
 				Subnet: awsproviderv1.AWSResourceReference{
 					Filters: []awsproviderv1.Filter{{
 						Name:   "tag:Name",
-						Values: []string{fmt.Sprintf("%s-private-%s", clusterID, "az")},
+						Values: []string{fmt.Sprintf("%s-private-%s", stubClusterID, "az")},
 					}},
 				},
 				IAMInstanceProfile: &awsproviderv1.AWSResourceReference{
@@ -492,7 +492,7 @@ func TestCreate(t *testing.T) {
 		machineScope, err := newMachineScope(machineScopeParams{
 			client:  fakeClient,
 			machine: machine,
-			awsClientBuilder: func(client runtimeclient.Client, secretName, namespace, region string) (awsclient.Client, error) {
+			awsClientBuilder: func(client runtimeclient.Client, secretName, namespace, region string, configManagedClient runtimeclient.Client) (awsclient.Client, error) {
 				return mockAWSClient, nil
 			},
 		})
@@ -638,7 +638,7 @@ func TestGetMachineInstances(t *testing.T) {
 			machineScope, err := newMachineScope(machineScopeParams{
 				client:  fakeClient,
 				machine: machineCopy,
-				awsClientBuilder: func(client runtimeclient.Client, secretName, namespace, region string) (awsclient.Client, error) {
+				awsClientBuilder: func(client runtimeclient.Client, secretName, namespace, region string, configManagedClient runtimeclient.Client) (awsclient.Client, error) {
 					return mockAWSClient, nil
 				},
 			})
